@@ -1,8 +1,10 @@
 import argparse
+import errno
 import math
 import os
 import shlex
 import shutil
+import socket
 import subprocess
 from datetime import datetime, timedelta
 from pathlib import Path
@@ -186,7 +188,7 @@ Double spaces means one space
     parser.add_argument(
         "--end", "-ve", help='Set the time to skip from the end of the media or use the magic word "dawsworth"'
     )
-    parser.add_argument("--player", "-player", help='Override the default player mpv; wt --player "vlc --vlc-opts"')
+    parser.add_argument("--player", "-player", help='Override the default player; wt --player "vlc --vlc-opts"')
     parser.add_argument("--mpv-socket", default="/tmp/mpv_socket")
 
     parser.add_argument(
@@ -276,13 +278,14 @@ Double spaces means one space
 
     log.info(filter_None(args.__dict__))
 
+    args.sock = None
     return args
 
 
 def transcode(next_video):
     temp_video = cmd("mktemp", "--suffix=.mkv", "--dry-run").stdout.strip()
     shutil.move(next_video, temp_video)
-    next_video = next_video.with_suffix(".mkv")
+    next_video = str(Path(next_video).with_suffix(".mkv"))
     cmd(
         (
             f"ffmpeg -loglevel error -stats -i {temp_video} -map 0 -scodec webvtt -vcodec h264"
@@ -298,8 +301,10 @@ def transcode(next_video):
 def delete_media(args, media_file):
     if len(args.prefix) > 0:
         media_file.unlink()
-    else:
+    elif which('trash-put') is not None:
         cmd("trash-put", media_file, strict=False)
+    else:
+        media_file.unlink()
 
     remove_media(args, str(media_file), quiet=True)
 
@@ -383,7 +388,7 @@ def watch_chromecast(args, m):
     return catt_log
 
 
-def listen_chromecast(args, m, player):
+def listen_chromecast(args, m):
     Path(CAST_NOW_PLAYING).write_text(m["path"])
     Path(FAKE_SUBTITLE).touch()
     if not args.with_local:
@@ -397,14 +402,14 @@ def listen_chromecast(args, m, player):
         )
         sleep(0.974)  # imperfect lazy sync; I use keyboard shortcuts to send `set speed` commands to mpv for resync
         # if pyChromecast provides a way to sync accurately that would be very interesting to know; I have not researched it
-        cmd_interactive(*player, "--", m["path"])
+        cmd_interactive(*args.player, "--", m["path"])
         catt_log = Pclose(cast_process)  # wait for chromecast to stop (you can tell any chromecast to pause)
         sleep(3.0)  # give chromecast some time to breathe
 
     return catt_log
 
 
-def calculate_duration(args, media, m):
+def calculate_duration(args, m):
     start = 0
     end = m.duration
 
@@ -421,17 +426,93 @@ def calculate_duration(args, media, m):
         else:
             end = args.end
 
-    if args.interdimensional_cable:
-        try:
-            bias_to_acts = m.index + 1 / len(media)
-            start = randrange(int(start * bias_to_acts), int(end - args.interdimensional_cable + 1))
-            end = start + args.interdimensional_cable
-        except:
-            pass
-
     return start, end
 
 
+def socket_play(args, m):
+    if args.sock is None:
+        subprocess.Popen(["mpv", "--idle", "--input-ipc-server=" + args.mpv_socket])
+        while not os.path.exists(args.mpv_socket):
+            sleep(0.2)
+        args.sock = socket.socket(socket.AF_UNIX)
+        args.sock.connect(args.mpv_socket)
+
+    start, end = calculate_duration(args, m)
+
+    try:
+        bias_to_acts = m.index + 1 / args.limit
+        start = randrange(int(start * bias_to_acts), int(end - args.interdimensional_cable + 1))
+        end = start + args.interdimensional_cable
+    except:
+        pass
+    if end == 0:
+        return
+
+    play_opts = f"start={start},save-position-on-quit=no"
+    if args.action in [Subcommand.listen, Subcommand.tubelisten]:
+        play_opts += ",video=no,really-quiet=yes"
+    elif args.action in [Subcommand.watch, Subcommand.tubewatch]:
+        play_opts += ",fullscreen=yes,force-window=yes,really-quiet=yes"
+
+    if args.action in [Subcommand.tubelisten, Subcommand.tubewatch]:
+        play_opts += ",script-opts=ytdl_hook-try_ytdl_first=yes"
+
+    f = m.path.replace("\\", "\\\\").replace('"', '\\"').replace("\n", "\\n")
+    args.sock.send((f'raw loadfile "{f}" replace "{play_opts}" \n').encode("utf-8"))
+    sleep(args.interdimensional_cable)
+
+
+def local_player(args, m, media_file):
+    if args.player:
+        player = args.player
+    elif which("mpv") is None:
+        player = ["xdg-open"]
+    else:
+        player = [which("mpv")]
+        if args.action in [Subcommand.listen, Subcommand.tubelisten]:
+            player.extend([f"--input-ipc-server={args.mpv_socket}", "--no-video", "--keep-open=no", "--really-quiet"])
+        elif args.action in [Subcommand.watch, Subcommand.tubewatch]:
+            player.extend(["--fs", "--force-window=yes", "--really-quiet"])
+
+        if args.action in [Subcommand.tubelisten, Subcommand.tubewatch]:
+            player.extend(["--script-opts=ytdl_hook-try_ytdl_first=yes"])
+
+        start, end = calculate_duration(args, m)
+        if end == 0:
+            return
+        if start != 0:
+            player.extend([f"--start={int(start)}", "--no-save-position-on-quit"])
+        if end != m.duration:
+            player.extend([f"--end={int(end)}"])
+
+    if args.action == Subcommand.watch:
+        if m["subtitle_count"] > 0:
+            player.extend(args.player_args_when_sub)
+        else:
+            player.extend(args.player_args_when_no_sub)
+
+    if args.action in [Subcommand.watch, Subcommand.tubewatch]:
+        cmd(*player, "--", media_file, strict=not args.ignore_errors)
+    elif args.action in [Subcommand.listen, Subcommand.tubelisten]:
+        cmd_interactive(*player, "--", media_file)
+
+
+def chromecast_play(args, m):
+    if args.action in [Subcommand.watch, Subcommand.tubewatch]:
+        catt_log = watch_chromecast(args, m)
+    elif args.action in [Subcommand.listen, Subcommand.tubelisten]:
+        catt_log = listen_chromecast(args, m)
+    else:
+        raise NotImplementedError
+
+    if catt_log:
+        if "Heartbeat timeout, resetting connection" in catt_log.stderr:
+            raise Exception("Media is possibly partially unwatched")
+
+        if catt_log.stderr == "":
+            raise Exception("catt does not exit nonzero? but something might have gone wrong")
+
+
 def play(args, media: pd.DataFrame):
     for m in media.to_records():
         media_file = m["path"]
@@ -455,65 +536,22 @@ def play(args, media: pd.DataFrame):
                 continue
             media_file = str(media_path)
 
-        if args.player:
-            player = args.player
-        elif which("mpv") is not None:
-            player = ["mpv"]
-            if args.action in [Subcommand.listen, Subcommand.tubelisten]:
-                player.extend(
-                    [f"--input-ipc-server={args.mpv_socket}", "--no-video", "--keep-open=no", "--really-quiet"]
-                )
-            elif args.action in [Subcommand.watch, Subcommand.tubewatch]:
-                player.extend(["--fs", "--force-window=yes", "--really-quiet"])
-
-            if args.action in [Subcommand.tubelisten, Subcommand.tubewatch]:
-                player.extend(["--script-opts=ytdl_hook-try_ytdl_first=yes"])
-
-            start, end = calculate_duration(args, media, m)
-            if end == 0:
-                continue
-            if start != 0:
-                player.extend([f"--start={int(start)}", "--no-save-position-on-quit"])
-            if end != m.duration:
-                player.extend([f"--end={int(end)}"])
-
-        else:
-            player = ["xdg-open"]
+            if args.transcode:
+                media_file = transcode(media_file)
 
         if args.action in [Subcommand.watch, Subcommand.tubewatch]:
             print(media_file)
         elif args.action == Subcommand.listen:
             print(cmd("ffprobe", "-hide_banner", "-loglevel", "info", media_file).stderr)
 
-        if args.transcode:
-            media_file = transcode(media_file)
-
         if args.chromecast:
-            if args.action in [Subcommand.watch, Subcommand.tubewatch]:
-                catt_log = watch_chromecast(args, m)
-            elif args.action in [Subcommand.listen, Subcommand.tubelisten]:
-                catt_log = listen_chromecast(args, m, player)
-            else:
-                raise NotImplementedError
+            chromecast_play(args, m)
 
-            if catt_log:
-                if "Heartbeat timeout, resetting connection" in catt_log.stderr:
-                    raise Exception("Media is possibly partially unwatched")
-
-                if catt_log.stderr == "":
-                    raise Exception("catt does not exit nonzero? but something might have gone wrong")
+        elif args.interdimensional_cable:
+            socket_play(args, m)
 
         else:
-            if args.action == Subcommand.watch:
-                if m["subtitle_count"] > 0:
-                    player.extend(args.player_args_when_sub)
-                else:
-                    player.extend(args.player_args_when_no_sub)
-
-            if args.action in [Subcommand.watch, Subcommand.tubewatch]:
-                cmd(*player, "--", media_file, strict=not args.ignore_errors)
-            elif args.action in [Subcommand.listen, Subcommand.tubelisten]:
-                cmd_interactive(*player, "--", media_file)
+            local_player(args, m, media_file)
 
         if args.post_action and not args.interdimensional_cable:
             post_act(args, media_file)
@@ -558,8 +596,7 @@ def construct_query(args):
     LIMIT = "LIMIT " + str(args.limit) if args.limit else ""
     OFFSET = f"OFFSET {args.skip}" if args.skip else ""
 
-    query = f"""
-    SELECT path
+    query = f"""SELECT path
         {', duration' if args.action != Subcommand.filesystem else ''}
         {', subtitle_count' if args.action == Subcommand.watch else ''}
         , size
@@ -627,7 +664,8 @@ def printer(args, query, bindings):
                 return printer(args, query, bindings)
             print(f)
         else:
-            print(db_resp[["path"]].to_string(index=False, header=False))
+            for line in db_resp[["path"]].to_string(index=False, header=False).splitlines():
+                print(line.strip())
     else:
         tbl = db_resp.copy()
         resize_col(tbl, "path", 22)
@@ -671,7 +709,11 @@ def process_actions(args):
         print("No media found")
         exit(2)
 
-    play(args, media)
+    try:
+        play(args, media)
+    finally:
+        cmd("pkill", "-f", f"mpv --idle --input-ipc-server={args.mpv_socket}", strict=False)
+        Path(args.mpv_socket).unlink(missing_ok=True)
 
 
 def watch():
